@@ -1,4 +1,4 @@
-# coding: utf8
+# coding: utf-8
 """
     cairocffi
     ~~~~~~~~~
@@ -11,17 +11,13 @@
 """
 
 import sys
+import ctypes.util
 
 from . import constants
 from .compat import FileNotFoundError
+from ._ffi import ffi
 
-try:
-    from ._ffi import ffi
-except ImportError:
-    # PyPy < 2.6 compatibility
-    from .ffi_build import ffi
-
-VERSION = '0.7.1'
+VERSION = '0.8.0'
 # pycairo compat:
 version = '1.10.0'
 version_info = (1, 10, 0)
@@ -30,17 +26,29 @@ version_info = (1, 10, 0)
 def dlopen(ffi, *names):
     """Try various names for the same library, for different platforms."""
     for name in names:
-        try:
-            return ffi.dlopen(name)
-        except OSError:
-            pass
-    # Re-raise the exception.
-    return ffi.dlopen(names[0])  # pragma: no cover
+        for lib_name in [name, 'lib' + name]:
+            try:
+                path = ctypes.util.find_library(lib_name)
+                if path:
+                    lib = ffi.dlopen(path)
+                    if lib:
+                        return lib
+            except OSError:
+                pass
+    raise OSError("dlopen() failed to load a library: %s" % ' / '.join(names))
 
 
-CAIRO_NAMES = ['libcairo.so.2', 'libcairo.2.dylib', 'libcairo-2.dll',
-               'cairo', 'libcairo-2']
-cairo = dlopen(ffi, *CAIRO_NAMES)
+cairo = dlopen(ffi, 'cairo', 'cairo-2')
+
+
+class _keepref(object):
+    """Function wrapper that keeps a reference to another object."""
+    def __init__(self, ref, func):
+        self.ref = ref
+        self.func = func
+
+    def __call__(self, *args, **kwargs):
+        self.func(*args, **kwargs)
 
 
 class CairoError(Exception):
@@ -102,7 +110,8 @@ def install_as_pycairo():
 # Implementation is in submodules, but public API is all here.
 
 from .surfaces import (Surface, ImageSurface, PDFSurface, PSSurface,
-                       SVGSurface, RecordingSurface, Win32PrintingSurface)
+                       SVGSurface, RecordingSurface, Win32Surface,
+                       Win32PrintingSurface)
 try:
     from .xcb import XCBSurface
 except ImportError:
